AccountData class

Constructors

AccountData({required double ledgerBalance, required double availableBalance, required double withdrawableBalance})
AccountData.fromJson(Map<String, dynamic> json)
factory

Properties

availableBalance double
final
hashCode int
The hash code for this object.
no setterinherited
ledgerBalance double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
withdrawableBalance double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited